# Table of Contents

- [diagram-templates](<./diagram-templates.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Diagram Templates](<./Diagram-Templates.md>)
  - [Overview](<./Diagram-Templates/Overview.md>)
  - [Key Features](<./Diagram-Templates/Key-Features.md>)
  - [Diagram Templates versus Standard Diagrams](<./Diagram-Templates/Diagram-Templates-versus-Standard-Diagrams.md>)
  - [Preset Diagram Templates](<./Diagram-Templates/Preset-Diagram-Templates.md>)
  - [Limitations](<./Diagram-Templates/Limitations.md>)
  - [Getting Started](<./Diagram-Templates/Getting-Started.md>)
  - [Managing Diagram Templates](<./Diagram-Templates/Managing-Diagram-Templates.md>)
  - [Diagram Template Permissions](<./Diagram-Templates/Diagram-Template-Permissions.md>)
  - [Best Practices](<./Diagram-Templates/Best-Practices.md>)
